@@ -1370,6 +1370,20 @@ typedef struct {
     CARD32 unused2 B32;
 } xGLXPbufferClobberEvent;
 
+typedef struct {
+    BYTE type;
+    BYTE pad;
+    CARD16 sequenceNumber B16;
+    CARD16 event_type B16;
+    CARD32 drawable;
+    CARD32 ust_hi B32;
+    CARD32 ust_lo B32;
+    CARD32 msc_hi B32;
+    CARD32 msc_lo B32;
+    CARD32 sbc_hi B32;
+    CARD32 sbc_lo B32;
+} xGLXBufferSwapComplete;
+
 typedef struct {
     BYTE type;
     BYTE pad;
@@ -1382,7 +1396,7 @@ typedef struct {
     CARD32 msc_hi B32;
     CARD32 msc_lo B32;
     CARD32 sbc B32;
-} xGLXBufferSwapComplete;
+} xGLXBufferSwapComplete2;
 
 /************************************************************************/
 
